# Purpose

The purpose of this change was to converge on a standardized way of using change handlers.

In Base Web we follow this event handler pattern:

- for custom handlers, or handler overrides with custom logic, we use the `onChange({event, value})` method signature,
- pass-through handlers, such as `onBlur` or `onMouseEnter` are not changed.

## Select

```diff
-  onChange: function(event, params)
+  onChange: function({event, type, option, selectedOption})
```

## Menu

```diff
-  function onItemSelect(item) {...}
+  function onItemSelect({item}) {...}
```

## Modal

```diff
-  function onClose(source) {...}
+  function onClose({source}) {...}
```

## Tag

```diff
-  function onActionClick(event, children) {...}
+  function onActionClick({event, children}) {...}
```

## Pagination

```diff
-  function onPrevClick(event) {...}
+  function onPrevClick({event}) {...}
```

```diff
-  function onNextClick(event) {...}
+  function onNextClick({event}) {...}
```

```diff
-  function onPageChange(nextPage, prevPage) {...}
+  function onPageChange({nextPage, prevPage}) {...}
```
