## Select

#### Styled component exports changed

```diff
- import {
-   StyledDropDown
-   StyledHint
-   StyledLabel
-   StyledOption
-   StyledSelectInput
-   StyledSelectSpinner
- } from 'baseui/select';
+  import {
+   StyledRoot,
+   StyledControlContainer,
+   StyledValueContainer,
+   StyledPlaceholder,
+   StyledSingleValue,
+   StyledInputContainer,
+   StyledInput,
+   StyledInputSizer,
+   StyledSelectArrow,
+   StyledClearIcon,
+   StyledSearchIcon,
+   StyledOptionContent,
+ } from 'baseui/select';
```

#### Removed `ICON` and `OPTIONS` from exports

```diff
- `import {ICON, OPTIONS} from 'baseui/select';`
```

#### `STATE_CHANGE_TYPE` changed to have `{select: string, remove: string, clear: string}` type

```diff
- `STATE_CHANGE_TYPE.unselect`
+ `STATE_CHANGE_TYPE.remove`
```

#### Use `value` prop instead of `selectedOptions`

```diff
-  <Select selectedOptions=[{id: 'someId', label: 'Some label'}] />
+  <Select value=[{id: 'someId', label: 'Some label'}] />
```

```diff
-  <StatefulSelect initialState={{selectedOptions: [{id: 'id'}]}} />
+  <StatefulSelect initialState={{value: [{id: 'someId', label: 'Some label'}] />
```

#### Use `multi` prop instead of `multiple`

```diff
-  <StatefulSelect multiple={true} />
+  <StatefulSelect multi={true} />
```

#### Use an `array` instead of a `func(query?: string) => Promise<Array<Object>>` type as a value of the `options` prop

```diff
- const options = textQuery => {
-   return new Promise(resolve => {
-     if (!textQuery) {
-       resolve([{id: 'someId', label: 'Some label'}])
-     } else {
-         fetch(url).then((resp) => resp.json()).then(resolve);
-     }
-   });
- };
-  <StatefulSelect options={options} />
+  <StatefulSelect options=[{id: 'someId', label: 'Some label'}] />
```

#### Use `getValueLabel: ({option: {}}) => React.Node` prop instead of `getSelectedOptionLabel: (option: Object) => React$Node`

```diff
-  <StatefulSelect getSelectedOptionLabel={(option) => option.label} />
+  <StatefulSelect getValueLabel={({option}) => option.label} />
```

#### Renamed `onTextInputChange` prop to `onInputChange`

```diff
-  <StatefulSelect onTextInputChange={e => {}} />
+  <StatefulSelect onInputChange={e => {}}/>
```

#### Changed `getOptionLabel` signature to `({option: {}) => React.Node`

```diff
-  <StatefulSelect getOptionLabel={(option) => option.label} />
+  <StatefulSelect getOptionLabel={({option}) => option.label} />
```

#### Changed `onChange` handler signature to `({value: Array<Object>, option: ?Object, type: $Keys<typeof STATE_CHANGE_TYPE>}) => {}`

```diff
-  <StatefulSelect onChange={({selectedOptions}) => {} />
+  <StatefulSelect onChange={({value}) => {} />
```

#### Removed `filterable` and `filterOption` props and introduces new `filterOptions: (options: Array<{}>, filterValue: string, excludeOptions: Array<{}>) => options: Array<{}>` and `filterOutSelected: boolean`

```diff
-  <StatefulSelect filterable={true} filterOption={(option) => false} />
+  <StatefulSelect filterOutSelected={false} />
```

#### Removed `tabindex` prop

```diff
-  <StatefulSelect tabindex={1} />
+  <StatefulSelect />
```

#### Removed `onMouseEnter` and `onMouseLeave` props

```diff
-  <StatefulSelect onMouseEnter={() => {}} onMouseLeave={() => {}} />
+  <StatefulSelect />
```

#### Overrides signature changed

```diff
-  `overrides: {Root, Input, SelectionContainer, Tag, SelectComponentIcon, SelectSpinner, DropDown, Option}`
+  `overrides: {Root, ControlContainer, Placeholder, ValueContainer, SingleValue, MultiValue, InputContainer, Input, SelectArrow, ClearIcon, LoadingIndicator, SearchIcon, DropDown, DropDownOption, OptionContent}`
```

#### See the [Select component RFC](https://github.com/uber-web/baseui/blob/master/src/select/README.md) for the detailed API and full list of added props
